/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Humanloop from "../../../index";
import * as fs from "fs";
import { Blob } from "buffer";
export declare namespace Datasets {
    interface Options {
        environment?: core.Supplier<environments.HumanloopEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
/**
 * Datasets are collections of input-output pairs that you can use within Humanloop for Evaluations.
 *
 * #### What is a Dataset?
 *
 * A Dataset is a collection of unique Datapoints. These Datapoints contain `inputs` and `target` fields. The `inputs`
 * are used to populate a Prompt's template and the `target` can be referenced by Evaluators to evaluate the quality of
 * the generated output.
 *
 * Note that Humanloop automatically deduplicates Datapoints. If you try to add a Datapoint that already exists, it will
 * be ignored. If you intentionally want to add a duplicate Datapoint, you can add a unique identifier to the Datapoint's
 * inputs such as `{_dedupe_id: <unique ID>}`.
 *
 * #### Creating Dataset versions
 *
 * Datasets have immutable versions. To add/remove Datapoint to/from an existing version, use the **Create** endpoint
 * and specify `action` as `"add"` or `"remove"` respectively. You may also specify the `version_id` or `environment`
 * query parameters to identify the existing version to base the new version on. If neither is provided, the version
 * deployed to the default Environment will be used.
 *
 */
export declare class Datasets {
    protected readonly _options: Datasets.Options;
    constructor(_options?: Datasets.Options);
    /**
     * List all Datasets.
     *
     * @param {Humanloop.ListDatasetsGetRequest} request
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.list({
     *         size: 1
     *     })
     */
    list(request?: Humanloop.ListDatasetsGetRequest, requestOptions?: Datasets.RequestOptions): Promise<core.Page<Humanloop.DatasetResponse>>;
    /**
     * Create a Dataset or update it with a new version if it already exists.
     *
     * Datasets are identified by the `ID` or their `path`. The datapoints determine the versions of the Dataset.
     *
     * By default, the new Dataset version will be set to the list of Datapoints provided in
     * the request. You can also create a new version by adding or removing Datapoints from an existing version
     * by specifying `action` as `add` or `remove` respectively. In this case, you may specify
     * the `version_id` or `environment` query parameters to identify the existing version to base
     * the new version on. If neither is provided, the latest created version will be used.
     *
     * You can provide `version_name` and `version_description` to identify and describe your versions.
     * Version names must be unique within a Dataset - attempting to create a version with a name
     * that already exists will result in a 409 Conflict error.
     *
     * Humanloop also deduplicates Datapoints. If you try to add a Datapoint that already
     * exists, it will be ignored. If you intentionally want to add a duplicate Datapoint,
     * you can add a unique identifier to the Datapoint's inputs such as `{_dedupe_id: <unique ID>}`.
     *
     * @param {Humanloop.DatasetRequest} request
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.upsert({
     *         path: "test-questions",
     *         datapoints: [{
     *                 inputs: {
     *                     "question": "What is the capital of France?"
     *                 },
     *                 target: {
     *                     "answer": "Paris"
     *                 }
     *             }, {
     *                 inputs: {
     *                     "question": "Who wrote Hamlet?"
     *                 },
     *                 target: {
     *                     "answer": "William Shakespeare"
     *                 }
     *             }],
     *         action: "set",
     *         versionName: "test-questions-v1",
     *         versionDescription: "Add two new questions and answers"
     *     })
     *
     * @example
     *     await client.datasets.upsert({
     *         path: "datasets/support-queries",
     *         datapoints: [{
     *                 messages: [{
     *                         role: "user",
     *                         content: "How do i manage my organizations API keys?\n"
     *                     }],
     *                 target: {
     *                     "response": "Hey, thanks for your questions. Here are steps for how to achieve: 1. Log in to the Humanloop Dashboard \n\n2. Click on \"Organization Settings.\"\n If you do not see this option, you might need to contact your organization admin to gain the necessary permissions.\n\n3. Within the settings or organization settings, select the option labeled \"API Keys\" on the left. Here you will be able to view and manage your API keys.\n\n4. You will see a list of existing API keys. You can perform various actions, such as:\n     - **Generate New API Key:** Click on the \"Generate New Key\" button if you need a new API key.\n     - **Revoke an API Key:** If you need to disable an existing key, find the key in the list and click the \"Revoke\" or \"Delete\" button.\n     - **Copy an API Key:** If you need to use an existing key, you can copy it to your clipboard by clicking the \"Copy\" button next to the key.\n\n5. **Save and Secure API Keys:** Make sure to securely store any new or existing API keys you are using. Treat them like passwords and do not share them publicly.\n\nIf you encounter any issues or need further assistance, it might be helpful to engage with an engineer or your IT department to ensure you have the necessary permissions and support.\n\nWould you need help with anything else?"
     *                 }
     *             }, {
     *                 messages: [{
     *                         role: "user",
     *                         content: "Hey, can do I use my code evaluator for monitoring my legal-copilot prompt?"
     *                     }],
     *                 target: {
     *                     "response": "Hey, thanks for your questions. Here are steps for how to achieve: 1. Navigate to your Prompt dashboard. \n 2. Select the `Monitoring` button on the top right of the Prompt dashboard \n 3. Within the model select the Version of the Evaluator you want to turn on for monitoring. \n\nWould you need help with anything else?"
     *                 }
     *             }],
     *         versionName: "Initial version",
     *         versionDescription: "Add two new questions and answers"
     *     })
     */
    upsert(request: Humanloop.DatasetRequest, requestOptions?: Datasets.RequestOptions): Promise<Humanloop.DatasetResponse>;
    /**
     * Retrieve the Dataset with the given ID.
     *
     * Unless `include_datapoints` is set to `true`, the response will not include
     * the Datapoints.
     * Use the List Datapoints endpoint (`GET /{id}/datapoints`) to efficiently
     * retrieve Datapoints for a large Dataset.
     *
     * By default, the deployed version of the Dataset is returned. Use the query parameters
     * `version_id` or `environment` to target a specific version of the Dataset.
     *
     * @param {string} id - Unique identifier for Dataset.
     * @param {Humanloop.GetDatasetsIdGetRequest} request
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.get("ds_b0baF1ca7652", {
     *         versionId: "dsv_6L78pqrdFi2xa",
     *         includeDatapoints: true
     *     })
     */
    get(id: string, request?: Humanloop.GetDatasetsIdGetRequest, requestOptions?: Datasets.RequestOptions): Promise<Humanloop.DatasetResponse>;
    /**
     * Delete the Dataset with the given ID.
     *
     * @param {string} id - Unique identifier for Dataset.
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.delete("id")
     */
    delete(id: string, requestOptions?: Datasets.RequestOptions): Promise<void>;
    /**
     * Move the Dataset to a different path or change the name.
     *
     * @param {string} id - Unique identifier for Dataset.
     * @param {Humanloop.UpdateDatasetRequest} request
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.move("id")
     */
    move(id: string, request?: Humanloop.UpdateDatasetRequest, requestOptions?: Datasets.RequestOptions): Promise<Humanloop.DatasetResponse>;
    /**
     * List all Datapoints for the Dataset with the given ID.
     *
     * @param {string} id - Unique identifier for Dataset.
     * @param {Humanloop.ListDatapointsDatasetsIdDatapointsGetRequest} request
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.listDatapoints("ds_b0baF1ca7652", {
     *         size: 1
     *     })
     */
    listDatapoints(id: string, request?: Humanloop.ListDatapointsDatasetsIdDatapointsGetRequest, requestOptions?: Datasets.RequestOptions): Promise<core.Page<Humanloop.DatapointResponse>>;
    /**
     * Get a list of the versions for a Dataset.
     *
     * @param {string} id - Unique identifier for Dataset.
     * @param {Humanloop.ListVersionsDatasetsIdVersionsGetRequest} request
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.listVersions("ds_b0baF1ca7652")
     */
    listVersions(id: string, request?: Humanloop.ListVersionsDatasetsIdVersionsGetRequest, requestOptions?: Datasets.RequestOptions): Promise<Humanloop.ListDatasets>;
    /**
     * Delete a version of the Dataset.
     *
     * @param {string} id - Unique identifier for Dataset.
     * @param {string} versionId - Unique identifier for the specific version of the Dataset.
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.deleteDatasetVersion("id", "version_id")
     */
    deleteDatasetVersion(id: string, versionId: string, requestOptions?: Datasets.RequestOptions): Promise<void>;
    /**
     * Update the name or description of the Dataset version.
     *
     * @param {string} id - Unique identifier for Dataset.
     * @param {string} versionId - Unique identifier for the specific version of the Dataset.
     * @param {Humanloop.UpdateVersionRequest} request
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.updateDatasetVersion("id", "version_id", {})
     */
    updateDatasetVersion(id: string, versionId: string, request: Humanloop.UpdateVersionRequest, requestOptions?: Datasets.RequestOptions): Promise<Humanloop.DatasetResponse>;
    /**
     * Add Datapoints from a CSV file to a Dataset.
     *
     * This will create a new version of the Dataset with the Datapoints from the CSV file.
     *
     * If either `version_id` or `environment` is provided, the new version will be based on the specified version,
     * with the Datapoints from the CSV file added to the existing Datapoints in the version.
     * If neither `version_id` nor `environment` is provided, the new version will be based on the version
     * of the Dataset that is deployed to the default Environment.
     *
     * You can optionally provide a name and description for the new version using `version_name`
     * and `version_description` parameters.
     *
     * @param {File | fs.ReadStream | Blob} file
     * @param {string} id
     * @param {Humanloop.BodyUploadCsvDatasetsIdDatapointsCsvPost} request
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.uploadCsv(fs.createReadStream("/path/to/your/file"), "id", {})
     */
    uploadCsv(file: File | fs.ReadStream | Blob, id: string, request: Humanloop.BodyUploadCsvDatasetsIdDatapointsCsvPost, requestOptions?: Datasets.RequestOptions): Promise<Humanloop.DatasetResponse>;
    /**
     * Deploy Dataset to Environment.
     *
     * Set the deployed version for the specified Environment.
     *
     * @param {string} id - Unique identifier for Dataset.
     * @param {string} environmentId - Unique identifier for the Environment to deploy the Version to.
     * @param {Humanloop.SetDeploymentDatasetsIdEnvironmentsEnvironmentIdPostRequest} request
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.setDeployment("ds_b0baF1ca7652", "staging", {
     *         versionId: "dsv_6L78pqrdFi2xa"
     *     })
     */
    setDeployment(id: string, environmentId: string, request: Humanloop.SetDeploymentDatasetsIdEnvironmentsEnvironmentIdPostRequest, requestOptions?: Datasets.RequestOptions): Promise<Humanloop.DatasetResponse>;
    /**
     * Remove deployed Dataset from Environment.
     *
     * Remove the deployed version for the specified Environment.
     *
     * @param {string} id - Unique identifier for Dataset.
     * @param {string} environmentId - Unique identifier for the Environment to remove the deployment from.
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.removeDeployment("ds_b0baF1ca7652", "staging")
     */
    removeDeployment(id: string, environmentId: string, requestOptions?: Datasets.RequestOptions): Promise<void>;
    /**
     * List all Environments and their deployed versions for the Dataset.
     *
     * @param {string} id - Unique identifier for Dataset.
     * @param {Datasets.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.datasets.listEnvironments("id")
     */
    listEnvironments(id: string, requestOptions?: Datasets.RequestOptions): Promise<Humanloop.FileEnvironmentResponse[]>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "X-API-KEY": string | undefined;
    }>;
}
