/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Humanloop from "../../../index";
export declare namespace Logs {
    interface Options {
        environment?: core.Supplier<environments.HumanloopEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
/**
 * Logs contain the inputs and outputs of each time a Prompt, Tool or Evaluator is called.
 *
 * Humanloop automatically records the inputs and outputs when you Call a Prompt or Tool and saves a Log.
 * Evaluator Logs are also created when an Evaluator is run on a Log.
 *
 * You can manually create Logs through the API.
 *
 * ...
 *
 *
 */
export declare class Logs {
    protected readonly _options: Logs.Options;
    constructor(_options?: Logs.Options);
    /**
     * List all Logs for the given filter criteria.
     *
     * @param {Humanloop.ListLogsGetRequest} request
     * @param {Logs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.logs.list({
     *         fileId: "file_123abc",
     *         size: 1
     *     })
     */
    list(request: Humanloop.ListLogsGetRequest, requestOptions?: Logs.RequestOptions): Promise<core.Page<Humanloop.LogResponse>>;
    /**
     * Delete Logs with the given IDs.
     *
     * @param {Humanloop.LogsDeleteRequest} request
     * @param {Logs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.logs.delete({
     *         id: "prv_Wu6zx1lAWJRqOyL8nWuZk"
     *     })
     */
    delete(request?: Humanloop.LogsDeleteRequest, requestOptions?: Logs.RequestOptions): Promise<void>;
    /**
     * Retrieve the Log with the given ID.
     *
     * @param {string} id - Unique identifier for Log.
     * @param {Logs.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.logs.get("prv_Wu6zx1lAWJRqOyL8nWuZk")
     */
    get(id: string, requestOptions?: Logs.RequestOptions): Promise<Humanloop.LogResponse>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "X-API-KEY": string | undefined;
    }>;
}
