/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Humanloop from "../../../index";
export declare namespace Prompts {
    interface Options {
        environment?: core.Supplier<environments.HumanloopEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
/**
 * Prompts define how a large language model behaves.
 *
 * #### What is a Prompt?
 *
 * A Prompt on Humanloop encapsulates the base instructions and other configuration for how a large language model should
 * perform a specific task.
 *
 * Prompts have immutable versions that you can **Save** and **Deploy**.
 * To use a Prompt, you can **Call** it to create a generation and you can **Log** generations manually.
 *
 * #### Referencing Prompts
 *
 * Prompts are referenced by their unique ID or path.
 *
 * You can perform actions on a specific Prompt version by specifying either the `version_id`
 * or `environment` query parameter in the request. If you provide a `version_id`, Humanloop will
 * use the specified version of the Prompt. If you provide an `environment`, Humanloop will use the
 * version of the Prompt that is currently deployed to that Environment.
 * If you do not provide either a `version_id` or `environment`, Humanloop will use the Prompt version
 * that is deployed to the default Environment.
 *
 */
export declare class Prompts {
    protected readonly _options: Prompts.Options;
    constructor(_options?: Prompts.Options);
    /**
     * Log to a Prompt.
     *
     * You can use query parameters `version_id`, or `environment`, to target
     * an existing version of the Prompt. Otherwise, the default deployed version will be chosen.
     *
     * Instead of targeting an existing version explicitly, you can instead pass in
     * Prompt details in the request body. In this case, we will check if the details correspond
     * to an existing version of the Prompt. If they do not, we will create a new version. This is helpful
     * in the case where you are storing or deriving your Prompt details in code.
     *
     * @param {Humanloop.PromptLogRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.log({
     *         path: "persona",
     *         prompt: {
     *             model: "gpt-4",
     *             template: [{
     *                     role: "system",
     *                     content: "You are {{person}}. Answer questions as this person. Do not break character."
     *                 }]
     *         },
     *         messages: [{
     *                 role: "user",
     *                 content: "What really happened at Roswell?"
     *             }],
     *         inputs: {
     *             "person": "Trump"
     *         },
     *         createdAt: "2024-07-19T00:29:35.178992",
     *         error: undefined,
     *         providerLatency: 6.5931549072265625,
     *         outputMessage: {
     *             content: "Well, you know, there is so much secrecy involved in government, folks, it's unbelievable. They don't want to tell you everything. They don't tell me everything! But about Roswell, it's a very popular question. I know, I just know, that something very, very peculiar happened there. Was it a weather balloon? Maybe. Was it something extraterrestrial? Could be. I'd love to go down and open up all the classified documents, believe me, I would. But they don't let that happen. The Deep State, folks, the Deep State. They're unbelievable. They want to keep everything a secret. But whatever the truth is, I can tell you this: it's something big, very very big. Tremendous, in fact.",
     *             role: "assistant"
     *         },
     *         promptTokens: 100,
     *         outputTokens: 220,
     *         promptCost: 0.00001,
     *         outputCost: 0.0002,
     *         finishReason: "stop"
     *     })
     */
    log(request?: Humanloop.PromptLogRequest, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.CreatePromptLogResponse>;
    /**
     * Update a Log.
     *
     * Update the details of a Log with the given ID.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {string} logId - Unique identifier for the Log.
     * @param {Humanloop.PromptLogUpdateRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.updateLog("id", "log_id")
     */
    updateLog(id: string, logId: string, request?: Humanloop.PromptLogUpdateRequest, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.LogResponse>;
    /**
     * Call a Prompt.
     *
     * Calling a Prompt calls the model provider before logging
     * the request, responses and metadata to Humanloop.
     *
     * You can use query parameters `version_id`, or `environment`, to target
     * an existing version of the Prompt. Otherwise the default deployed version will be chosen.
     *
     * Instead of targeting an existing version explicitly, you can instead pass in
     * Prompt details in the request body. In this case, we will check if the details correspond
     * to an existing version of the Prompt. If they do not, we will create a new version. This is helpful
     * in the case where you are storing or deriving your Prompt details in code.
     */
    callStream(request: Humanloop.PromptsCallStreamRequest, requestOptions?: Prompts.RequestOptions): Promise<core.Stream<Humanloop.PromptCallStreamResponse>>;
    /**
     * Call a Prompt.
     *
     * Calling a Prompt calls the model provider before logging
     * the request, responses and metadata to Humanloop.
     *
     * You can use query parameters `version_id`, or `environment`, to target
     * an existing version of the Prompt. Otherwise the default deployed version will be chosen.
     *
     * Instead of targeting an existing version explicitly, you can instead pass in
     * Prompt details in the request body. In this case, we will check if the details correspond
     * to an existing version of the Prompt. If they do not, we will create a new version. This is helpful
     * in the case where you are storing or deriving your Prompt details in code.
     *
     * @param {Humanloop.PromptsCallRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.call({
     *         path: "persona",
     *         prompt: {
     *             model: "gpt-4",
     *             template: [{
     *                     role: "system",
     *                     content: "You are stockbot. Return latest prices."
     *                 }],
     *             tools: [{
     *                     name: "get_stock_price",
     *                     description: "Get current stock price",
     *                     parameters: {
     *                         "type": "object",
     *                         "properties": {
     *                             "ticker_symbol": {
     *                                 "type": "string",
     *                                 "name": "Ticker Symbol",
     *                                 "description": "Ticker symbol of the stock"
     *                             }
     *                         },
     *                         "required": []
     *                     }
     *                 }]
     *         },
     *         messages: [{
     *                 role: "user",
     *                 content: "latest apple"
     *             }]
     *     })
     *
     * @example
     *     await client.prompts.call({
     *         path: "persona",
     *         prompt: {
     *             model: "gpt-4",
     *             template: [{
     *                     role: "system",
     *                     content: "You are {{person}}. Answer any questions as this person. Do not break character."
     *                 }]
     *         },
     *         messages: [{
     *                 role: "user",
     *                 content: "What really happened at Roswell?"
     *             }],
     *         inputs: {
     *             "person": "Trump"
     *         }
     *     })
     *
     * @example
     *     await client.prompts.call({
     *         versionId: "prv_Wu6zx1lAWJRqOyL8nWuZk",
     *         path: "persona",
     *         messages: [{
     *                 role: "user",
     *                 content: "What really happened at Roswell?"
     *             }],
     *         inputs: {
     *             "person": "Trump"
     *         }
     *     })
     */
    call(request: Humanloop.PromptsCallRequest, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.PromptCallResponse>;
    /**
     * Get a list of all Prompts.
     *
     * @param {Humanloop.ListPromptsGetRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.list({
     *         size: 1
     *     })
     */
    list(request?: Humanloop.ListPromptsGetRequest, requestOptions?: Prompts.RequestOptions): Promise<core.Page<Humanloop.PromptResponse>>;
    /**
     * Create a Prompt or update it with a new version if it already exists.
     *
     * Prompts are identified by the `ID` or their `path`. The parameters (i.e. the prompt template, temperature, model etc.) determine the versions of the Prompt.
     *
     * You can provide `version_name` and `version_description` to identify and describe your versions.
     * Version names must be unique within a Prompt - attempting to create a version with a name
     * that already exists will result in a 409 Conflict error.
     *
     * @param {Humanloop.PromptRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.upsert({
     *         path: "Personal Projects/Coding Assistant",
     *         model: "gpt-4o",
     *         endpoint: "chat",
     *         template: [{
     *                 content: "You are a helpful coding assistant specialising in {{language}}",
     *                 role: "system"
     *             }],
     *         provider: "openai",
     *         maxTokens: -1,
     *         temperature: 0.7,
     *         versionName: "coding-assistant-v1",
     *         versionDescription: "Initial version"
     *     })
     */
    upsert(request: Humanloop.PromptRequest, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.PromptResponse>;
    /**
     * Retrieve the Prompt with the given ID.
     *
     * By default, the deployed version of the Prompt is returned. Use the query parameters
     * `version_id` or `environment` to target a specific version of the Prompt.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {Humanloop.GetPromptsIdGetRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.get("pr_30gco7dx6JDq4200GVOHa")
     */
    get(id: string, request?: Humanloop.GetPromptsIdGetRequest, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.PromptResponse>;
    /**
     * Delete the Prompt with the given ID.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.delete("pr_30gco7dx6JDq4200GVOHa")
     */
    delete(id: string, requestOptions?: Prompts.RequestOptions): Promise<void>;
    /**
     * Move the Prompt to a different path or change the name.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {Humanloop.UpdatePromptRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.move("pr_30gco7dx6JDq4200GVOHa", {
     *         path: "new directory/new name"
     *     })
     */
    move(id: string, request?: Humanloop.UpdatePromptRequest, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.PromptResponse>;
    /**
     * Retrieve the Prompt with the given ID, including the populated template.
     *
     * By default, the deployed version of the Prompt is returned. Use the query parameters
     * `version_id` or `environment` to target a specific version of the Prompt.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {Humanloop.PopulatePromptsIdPopulatePostRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.populate("id", {
     *         body: {
     *             "key": "value"
     *         }
     *     })
     */
    populate(id: string, request: Humanloop.PopulatePromptsIdPopulatePostRequest, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.PopulateTemplateResponse>;
    /**
     * Get a list of all the versions of a Prompt.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {Humanloop.ListVersionsPromptsIdVersionsGetRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.listVersions("pr_30gco7dx6JDq4200GVOHa")
     */
    listVersions(id: string, request?: Humanloop.ListVersionsPromptsIdVersionsGetRequest, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.ListPrompts>;
    /**
     * Delete a version of the Prompt.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {string} versionId - Unique identifier for the specific version of the Prompt.
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.deletePromptVersion("id", "version_id")
     */
    deletePromptVersion(id: string, versionId: string, requestOptions?: Prompts.RequestOptions): Promise<void>;
    /**
     * Update the name or description of the Prompt version.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {string} versionId - Unique identifier for the specific version of the Prompt.
     * @param {Humanloop.UpdateVersionRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.patchPromptVersion("id", "version_id", {})
     */
    patchPromptVersion(id: string, versionId: string, request: Humanloop.UpdateVersionRequest, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.PromptResponse>;
    /**
     * Deploy Prompt to an Environment.
     *
     * Set the deployed version for the specified Environment. This Prompt
     * will be used for calls made to the Prompt in this Environment.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {string} environmentId - Unique identifier for the Environment to deploy the Version to.
     * @param {Humanloop.SetDeploymentPromptsIdEnvironmentsEnvironmentIdPostRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.setDeployment("id", "environment_id", {
     *         versionId: "version_id"
     *     })
     */
    setDeployment(id: string, environmentId: string, request: Humanloop.SetDeploymentPromptsIdEnvironmentsEnvironmentIdPostRequest, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.PromptResponse>;
    /**
     * Remove deployed Prompt from the Environment.
     *
     * Remove the deployed version for the specified Environment. This Prompt
     * will no longer be used for calls made to the Prompt in this Environment.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {string} environmentId - Unique identifier for the Environment to remove the deployment from.
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.removeDeployment("id", "environment_id")
     */
    removeDeployment(id: string, environmentId: string, requestOptions?: Prompts.RequestOptions): Promise<void>;
    /**
     * List all Environments and their deployed versions for the Prompt.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.listEnvironments("pr_30gco7dx6JDq4200GVOHa")
     */
    listEnvironments(id: string, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.FileEnvironmentResponse[]>;
    /**
     * Activate and deactivate Evaluators for monitoring the Prompt.
     *
     * An activated Evaluator will automatically be run on all new Logs
     * within the Prompt for monitoring purposes.
     *
     * @param {string} id
     * @param {Humanloop.EvaluatorActivationDeactivationRequest} request
     * @param {Prompts.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.prompts.updateMonitoring("pr_30gco7dx6JDq4200GVOHa", {
     *         activate: [{
     *                 evaluatorVersionId: "evv_1abc4308abd"
     *             }]
     *     })
     */
    updateMonitoring(id: string, request: Humanloop.EvaluatorActivationDeactivationRequest, requestOptions?: Prompts.RequestOptions): Promise<Humanloop.PromptResponse>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "X-API-KEY": string | undefined;
    }>;
}
