import { Tracer } from "@opentelemetry/api";
import { ToolKernelRequest } from "../api/types/ToolKernelRequest";
/**
 * Higher-order function for wrapping a function with OpenTelemetry instrumentation.
 * It inspects the argument signature of the wrapped function to build a JSON schema.
 *
 * @param func - The function to wrap
 * @param opentelemetryTracer - The OpenTelemetry tracer instance
 * @param path - Optional span path
 * @param version - Additional metadata for the function
 * @returns Wrapped function with OpenTelemetry instrumentation
 */
export declare function toolUtilityFactory<I, O>(opentelemetryTracer: Tracer, callable: (inputs: I) => O, version: ToolKernelRequest, path: string): (inputs: I) => O & {
    jsonSchema: Record<string, unknown>;
};
