/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Humanloop from "../../../index";
export declare namespace Evaluators {
    interface Options {
        environment?: core.Supplier<environments.HumanloopEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Evaluators {
    protected readonly _options: Evaluators.Options;
    constructor(_options?: Evaluators.Options);
    /**
     * Submit Evaluator judgment for an existing Log.
     *
     * Creates a new Log. The evaluated Log will be set as the parent of the created Log.
     *
     * @param {Humanloop.CreateEvaluatorLogRequest} request
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.log({
     *         parentId: "parent_id"
     *     })
     */
    log(request: Humanloop.CreateEvaluatorLogRequest, requestOptions?: Evaluators.RequestOptions): Promise<Humanloop.CreateEvaluatorLogResponse>;
    /**
     * Get a list of all Evaluators.
     *
     * @param {Humanloop.ListEvaluatorsGetRequest} request
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.list({
     *         size: 1
     *     })
     */
    list(request?: Humanloop.ListEvaluatorsGetRequest, requestOptions?: Evaluators.RequestOptions): Promise<core.Page<Humanloop.EvaluatorResponse>>;
    /**
     * Create an Evaluator or update it with a new version if it already exists.
     *
     * Evaluators are identified by the `ID` or their `path`. The spec provided determines the version of the Evaluator.
     *
     * You can provide `version_name` and `version_description` to identify and describe your versions.
     * Version names must be unique within an Evaluator - attempting to create a version with a name
     * that already exists will result in a 409 Conflict error.
     *
     * @param {Humanloop.EvaluatorRequest} request
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.upsert({
     *         path: "Shared Evaluators/Accuracy Evaluator",
     *         spec: {
     *             argumentsType: "target_required",
     *             returnType: "number",
     *             evaluatorType: "python",
     *             code: "def evaluate(answer, target):\n    return 0.5"
     *         },
     *         versionName: "simple-evaluator",
     *         versionDescription: "Simple evaluator that returns 0.5"
     *     })
     */
    upsert(request: Humanloop.EvaluatorRequest, requestOptions?: Evaluators.RequestOptions): Promise<Humanloop.EvaluatorResponse>;
    /**
     * Retrieve the Evaluator with the given ID.
     *
     * By default, the deployed version of the Evaluator is returned. Use the query parameters
     * `version_id` or `environment` to target a specific version of the Evaluator.
     *
     * @param {string} id - Unique identifier for Evaluator.
     * @param {Humanloop.GetEvaluatorsIdGetRequest} request
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.get("ev_890bcd")
     */
    get(id: string, request?: Humanloop.GetEvaluatorsIdGetRequest, requestOptions?: Evaluators.RequestOptions): Promise<Humanloop.EvaluatorResponse>;
    /**
     * Delete the Evaluator with the given ID.
     *
     * @param {string} id - Unique identifier for Evaluator.
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.delete("ev_890bcd")
     */
    delete(id: string, requestOptions?: Evaluators.RequestOptions): Promise<void>;
    /**
     * Move the Evaluator to a different path or change the name.
     *
     * @param {string} id - Unique identifier for Evaluator.
     * @param {Humanloop.UpdateEvaluatorRequest} request
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.move("ev_890bcd", {
     *         path: "new directory/new name"
     *     })
     */
    move(id: string, request?: Humanloop.UpdateEvaluatorRequest, requestOptions?: Evaluators.RequestOptions): Promise<Humanloop.EvaluatorResponse>;
    /**
     * Get a list of all the versions of an Evaluator.
     *
     * @param {string} id - Unique identifier for the Evaluator.
     * @param {Humanloop.ListVersionsEvaluatorsIdVersionsGetRequest} request
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.listVersions("ev_890bcd")
     */
    listVersions(id: string, request?: Humanloop.ListVersionsEvaluatorsIdVersionsGetRequest, requestOptions?: Evaluators.RequestOptions): Promise<Humanloop.ListEvaluators>;
    /**
     * Delete a version of the Evaluator.
     *
     * @param {string} id - Unique identifier for Evaluator.
     * @param {string} versionId - Unique identifier for the specific version of the Evaluator.
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.deleteEvaluatorVersion("id", "version_id")
     */
    deleteEvaluatorVersion(id: string, versionId: string, requestOptions?: Evaluators.RequestOptions): Promise<void>;
    /**
     * Update the name or description of the Evaluator version.
     *
     * @param {string} id - Unique identifier for Evaluator.
     * @param {string} versionId - Unique identifier for the specific version of the Evaluator.
     * @param {Humanloop.UpdateVersionRequest} request
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.updateEvaluatorVersion("id", "version_id", {})
     */
    updateEvaluatorVersion(id: string, versionId: string, request: Humanloop.UpdateVersionRequest, requestOptions?: Evaluators.RequestOptions): Promise<Humanloop.EvaluatorResponse>;
    /**
     * Deploy Evaluator to an Environment.
     *
     * Set the deployed version for the specified Environment. This Evaluator
     * will be used for calls made to the Evaluator in this Environment.
     *
     * @param {string} id - Unique identifier for Evaluator.
     * @param {string} environmentId - Unique identifier for the Environment to deploy the Version to.
     * @param {Humanloop.SetDeploymentEvaluatorsIdEnvironmentsEnvironmentIdPostRequest} request
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.setDeployment("ev_890bcd", "staging", {
     *         versionId: "evv_012def"
     *     })
     */
    setDeployment(id: string, environmentId: string, request: Humanloop.SetDeploymentEvaluatorsIdEnvironmentsEnvironmentIdPostRequest, requestOptions?: Evaluators.RequestOptions): Promise<Humanloop.EvaluatorResponse>;
    /**
     * Remove deployed Evaluator from the Environment.
     *
     * Remove the deployed version for the specified Environment. This Evaluator
     * will no longer be used for calls made to the Evaluator in this Environment.
     *
     * @param {string} id - Unique identifier for Evaluator.
     * @param {string} environmentId - Unique identifier for the Environment to remove the deployment from.
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.removeDeployment("ev_890bcd", "staging")
     */
    removeDeployment(id: string, environmentId: string, requestOptions?: Evaluators.RequestOptions): Promise<void>;
    /**
     * List all Environments and their deployed versions for the Evaluator.
     *
     * @param {string} id - Unique identifier for Evaluator.
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.listEnvironments("ev_890bcd")
     */
    listEnvironments(id: string, requestOptions?: Evaluators.RequestOptions): Promise<Humanloop.FileEnvironmentResponse[]>;
    /**
     * Activate and deactivate Evaluators for monitoring the Evaluator.
     *
     * An activated Evaluator will automatically be run on all new Logs
     * within the Evaluator for monitoring purposes.
     *
     * @param {string} id
     * @param {Humanloop.EvaluatorActivationDeactivationRequest} request
     * @param {Evaluators.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.evaluators.updateMonitoring("id", {})
     */
    updateMonitoring(id: string, request: Humanloop.EvaluatorActivationDeactivationRequest, requestOptions?: Evaluators.RequestOptions): Promise<Humanloop.EvaluatorResponse>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "X-API-KEY": string | undefined;
    }>;
}
