/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Humanloop from "../../../index";
export declare namespace Flows {
    interface Options {
        environment?: core.Supplier<environments.HumanloopEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Flows {
    protected readonly _options: Flows.Options;
    constructor(_options?: Flows.Options);
    /**
     * Log to a Flow.
     *
     * You can use query parameters `version_id`, or `environment`, to target
     * an existing version of the Flow. Otherwise, the default deployed version will be chosen.
     *
     * If you create the Flow Log with a `log_status` of `incomplete`, you should later update it to `complete`
     * in order to trigger Evaluators.
     *
     * @param {Humanloop.FlowLogRequest} request
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.log({
     *         id: "fl_6o701g4jmcanPVHxdqD0O",
     *         flow: {
     *             attributes: {
     *                 "prompt": {
     *                     "template": "You are a helpful assistant helping with medical anamnesis",
     *                     "model": "gpt-4o",
     *                     "temperature": 0.8
     *                 },
     *                 "tool": {
     *                     "name": "retrieval_tool_v3",
     *                     "description": "Retrieval tool for MedQA.",
     *                     "source_code": "def retrieval_tool(question: str) -> str:\n    pass\n"
     *                 }
     *             }
     *         },
     *         inputs: {
     *             "question": "Patient with a history of diabetes and hypertension presents with chest pain and shortness of breath."
     *         },
     *         output: "The patient is likely experiencing a myocardial infarction. Immediate medical attention is required.",
     *         logStatus: "incomplete",
     *         startTime: "2024-07-08T22:40:35",
     *         endTime: "2024-07-08T22:40:39"
     *     })
     */
    log(request?: Humanloop.FlowLogRequest, requestOptions?: Flows.RequestOptions): Promise<Humanloop.CreateFlowLogResponse>;
    /**
     * Update the status, inputs, output of a Flow Log.
     *
     * Marking a Flow Log as complete will trigger any monitoring Evaluators to run.
     * Inputs and output (or error) must be provided in order to mark it as complete.
     *
     * The end_time log attribute will be set to match the time the log is marked as complete.
     *
     * @param {string} logId - Unique identifier of the Flow Log.
     * @param {Humanloop.UpdateFlowLogRequest} request
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.updateLog("medqa_experiment_0001", {
     *         inputs: {
     *             "question": "Patient with a history of diabetes and normal tension presents with chest pain and shortness of breath."
     *         },
     *         output: "The patient is likely experiencing a myocardial infarction. Immediate medical attention is required.",
     *         logStatus: "complete",
     *         error: undefined
     *     })
     */
    updateLog(logId: string, request?: Humanloop.UpdateFlowLogRequest, requestOptions?: Flows.RequestOptions): Promise<Humanloop.FlowLogResponse>;
    /**
     * Retrieve the Flow with the given ID.
     *
     * By default, the deployed version of the Flow is returned. Use the query parameters
     * `version_id` or `environment` to target a specific version of the Flow.
     *
     * @param {string} id - Unique identifier for Flow.
     * @param {Humanloop.GetFlowsIdGetRequest} request
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.get("fl_6o701g4jmcanPVHxdqD0O")
     */
    get(id: string, request?: Humanloop.GetFlowsIdGetRequest, requestOptions?: Flows.RequestOptions): Promise<Humanloop.FlowResponse>;
    /**
     * Delete the Flow with the given ID.
     *
     * @param {string} id - Unique identifier for Flow.
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.delete("fl_6o701g4jmcanPVHxdqD0O")
     */
    delete(id: string, requestOptions?: Flows.RequestOptions): Promise<void>;
    /**
     * Move the Flow to a different path or change the name.
     *
     * @param {string} id - Unique identifier for Flow.
     * @param {Humanloop.UpdateFlowRequest} request
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.move("fl_6o701g4jmcanPVHxdqD0O", {
     *         path: "new directory/new name"
     *     })
     */
    move(id: string, request?: Humanloop.UpdateFlowRequest, requestOptions?: Flows.RequestOptions): Promise<Humanloop.FlowResponse>;
    /**
     * Get a list of Flows.
     *
     * @param {Humanloop.ListFlowsGetRequest} request
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.list({
     *         size: 1
     *     })
     */
    list(request?: Humanloop.ListFlowsGetRequest, requestOptions?: Flows.RequestOptions): Promise<core.Page<Humanloop.FlowResponse>>;
    /**
     * Create or update a Flow.
     *
     * Flows can also be identified by the `ID` or their `path`.
     *
     * You can provide `version_name` and `version_description` to identify and describe your versions.
     * Version names must be unique within a Flow - attempting to create a version with a name
     * that already exists will result in a 409 Conflict error.
     *
     * @param {Humanloop.FlowRequest} request
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.upsert({
     *         path: "Personal Projects/MedQA Flow",
     *         attributes: {
     *             "prompt": {
     *                 "template": "You are a helpful medical assistant helping with medical anamnesis. Answer {{question}}",
     *                 "model": "gpt-4o",
     *                 "temperature": 0.8
     *             },
     *             "tool": {
     *                 "name": "retrieval_tool_v3",
     *                 "description": "Retrieval tool for MedQA.",
     *                 "source_code": "def retrieval_tool(question: str) -> str:\n    pass\n"
     *             },
     *             "version_name": "medqa-flow-v1",
     *             "version_description": "Initial version"
     *         }
     *     })
     */
    upsert(request: Humanloop.FlowRequest, requestOptions?: Flows.RequestOptions): Promise<Humanloop.FlowResponse>;
    /**
     * Get a list of all the versions of a Flow.
     *
     * @param {string} id - Unique identifier for Flow.
     * @param {Humanloop.ListVersionsFlowsIdVersionsGetRequest} request
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.listVersions("fl_6o701g4jmcanPVHxdqD0O")
     */
    listVersions(id: string, request?: Humanloop.ListVersionsFlowsIdVersionsGetRequest, requestOptions?: Flows.RequestOptions): Promise<Humanloop.ListFlows>;
    /**
     * Delete a version of the Flow.
     *
     * @param {string} id - Unique identifier for Flow.
     * @param {string} versionId - Unique identifier for the specific version of the Flow.
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.deleteFlowVersion("id", "version_id")
     */
    deleteFlowVersion(id: string, versionId: string, requestOptions?: Flows.RequestOptions): Promise<void>;
    /**
     * Update the name or description of the Flow version.
     *
     * @param {string} id - Unique identifier for Flow.
     * @param {string} versionId - Unique identifier for the specific version of the Flow.
     * @param {Humanloop.UpdateVersionRequest} request
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.updateFlowVersion("id", "version_id", {})
     */
    updateFlowVersion(id: string, versionId: string, request: Humanloop.UpdateVersionRequest, requestOptions?: Flows.RequestOptions): Promise<Humanloop.FlowResponse>;
    /**
     * Deploy Flow to an Environment.
     *
     * Set the deployed version for the specified Environment. This Flow
     * will be used for calls made to the Flow in this Environment.
     *
     * @param {string} id - Unique identifier for Flow.
     * @param {string} environmentId - Unique identifier for the Environment to deploy the Version to.
     * @param {Humanloop.SetDeploymentFlowsIdEnvironmentsEnvironmentIdPostRequest} request
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.setDeployment("fl_6o701g4jmcanPVHxdqD0O", "staging", {
     *         versionId: "flv_6o701g4jmcanPVHxdqD0O"
     *     })
     */
    setDeployment(id: string, environmentId: string, request: Humanloop.SetDeploymentFlowsIdEnvironmentsEnvironmentIdPostRequest, requestOptions?: Flows.RequestOptions): Promise<Humanloop.FlowResponse>;
    /**
     * Remove deployed Flow from the Environment.
     *
     * Remove the deployed version for the specified Environment. This Flow
     * will no longer be used for calls made to the Flow in this Environment.
     *
     * @param {string} id - Unique identifier for Flow.
     * @param {string} environmentId - Unique identifier for the Environment to remove the deployment from.
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.removeDeployment("fl_6o701g4jmcanPVHxdqD0O", "staging")
     */
    removeDeployment(id: string, environmentId: string, requestOptions?: Flows.RequestOptions): Promise<void>;
    /**
     * List all Environments and their deployed versions for the Flow.
     *
     * @param {string} id - Unique identifier for Flow.
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.listEnvironments("fl_6o701g4jmcanPVHxdqD0O")
     */
    listEnvironments(id: string, requestOptions?: Flows.RequestOptions): Promise<Humanloop.FileEnvironmentResponse[]>;
    /**
     * Activate and deactivate Evaluators for monitoring the Flow.
     *
     * An activated Evaluator will automatically be run on all new "completed" Logs
     * within the Flow for monitoring purposes.
     *
     * @param {string} id
     * @param {Humanloop.EvaluatorActivationDeactivationRequest} request
     * @param {Flows.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.flows.updateMonitoring("fl_6o701g4jmcanPVHxdqD0O", {
     *         activate: [{
     *                 evaluatorVersionId: "evv_1abc4308abd"
     *             }]
     *     })
     */
    updateMonitoring(id: string, request: Humanloop.EvaluatorActivationDeactivationRequest, requestOptions?: Flows.RequestOptions): Promise<Humanloop.FlowResponse>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "X-API-KEY": string | undefined;
    }>;
}
