/**
 * This file was auto-generated by Fern from our API Definition.
 */
import * as environments from "../../../../environments";
import * as core from "../../../../core";
import * as Humanloop from "../../../index";
export declare namespace Tools {
    interface Options {
        environment?: core.Supplier<environments.HumanloopEnvironment | string>;
        /** Specify a custom URL to connect the client to. */
        baseUrl?: core.Supplier<string>;
        apiKey?: core.Supplier<string>;
        fetcher?: core.FetchFunction;
    }
    interface RequestOptions {
        /** The maximum time to wait for a response in seconds. */
        timeoutInSeconds?: number;
        /** The number of times to retry the request. Defaults to 2. */
        maxRetries?: number;
        /** A hook to abort the request. */
        abortSignal?: AbortSignal;
        /** Additional headers to include in the request. */
        headers?: Record<string, string>;
    }
}
export declare class Tools {
    protected readonly _options: Tools.Options;
    constructor(_options?: Tools.Options);
    /**
     * Log to a Tool.
     *
     * You can use query parameters `version_id`, or `environment`, to target
     * an existing version of the Tool. Otherwise the default deployed version will be chosen.
     *
     * Instead of targeting an existing version explicitly, you can instead pass in
     * Tool details in the request body. In this case, we will check if the details correspond
     * to an existing version of the Tool, if not we will create a new version. This is helpful
     * in the case where you are storing or deriving your Tool details in code.
     *
     * @param {Humanloop.ToolLogRequest} request
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.log({
     *         path: "math-tool",
     *         tool: {
     *             function: {
     *                 name: "multiply",
     *                 description: "Multiply two numbers",
     *                 parameters: {
     *                     "type": "object",
     *                     "properties": {
     *                         "a": {
     *                             "type": "number"
     *                         },
     *                         "b": {
     *                             "type": "number"
     *                         }
     *                     },
     *                     "required": [
     *                         "a",
     *                         "b"
     *                     ]
     *                 }
     *             }
     *         },
     *         inputs: {
     *             "a": 5,
     *             "b": 7
     *         },
     *         output: "35"
     *     })
     */
    log(request?: Humanloop.ToolLogRequest, requestOptions?: Tools.RequestOptions): Promise<Humanloop.CreateToolLogResponse>;
    /**
     * Update a Log.
     *
     * Update the details of a Log with the given ID.
     *
     * @param {string} id - Unique identifier for Prompt.
     * @param {string} logId - Unique identifier for the Log.
     * @param {Humanloop.ToolLogUpdateRequest} request
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.update("id", "log_id")
     */
    update(id: string, logId: string, request?: Humanloop.ToolLogUpdateRequest, requestOptions?: Tools.RequestOptions): Promise<Humanloop.LogResponse>;
    /**
     * Get a list of all Tools.
     *
     * @param {Humanloop.ListToolsGetRequest} request
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.list({
     *         size: 1
     *     })
     */
    list(request?: Humanloop.ListToolsGetRequest, requestOptions?: Tools.RequestOptions): Promise<core.Page<Humanloop.ToolResponse>>;
    /**
     * Create a Tool or update it with a new version if it already exists.
     *
     * Tools are identified by the `ID` or their `path`. The name, description and parameters determine the versions of the Tool.
     *
     * You can provide `version_name` and `version_description` to identify and describe your versions.
     * Version names must be unique within a Tool - attempting to create a version with a name
     * that already exists will result in a 409 Conflict error.
     *
     * @param {Humanloop.ToolRequest} request
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.upsert({
     *         path: "math-tool",
     *         function: {
     *             name: "multiply",
     *             description: "Multiply two numbers",
     *             parameters: {
     *                 "type": "object",
     *                 "properties": {
     *                     "a": {
     *                         "type": "number"
     *                     },
     *                     "b": {
     *                         "type": "number"
     *                     }
     *                 },
     *                 "required": [
     *                     "a",
     *                     "b"
     *                 ]
     *             }
     *         },
     *         versionName: "math-tool-v1",
     *         versionDescription: "Simple math tool that multiplies two numbers"
     *     })
     */
    upsert(request?: Humanloop.ToolRequest, requestOptions?: Tools.RequestOptions): Promise<Humanloop.ToolResponse>;
    /**
     * Retrieve the Tool with the given ID.
     *
     * By default, the deployed version of the Tool is returned. Use the query parameters
     * `version_id` or `environment` to target a specific version of the Tool.
     *
     * @param {string} id - Unique identifier for Tool.
     * @param {Humanloop.GetToolsIdGetRequest} request
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.get("tl_789ghi")
     */
    get(id: string, request?: Humanloop.GetToolsIdGetRequest, requestOptions?: Tools.RequestOptions): Promise<Humanloop.ToolResponse>;
    /**
     * Delete the Tool with the given ID.
     *
     * @param {string} id - Unique identifier for Tool.
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.delete("tl_789ghi")
     */
    delete(id: string, requestOptions?: Tools.RequestOptions): Promise<void>;
    /**
     * Move the Tool to a different path or change the name.
     *
     * @param {string} id - Unique identifier for Tool.
     * @param {Humanloop.UpdateToolRequest} request
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.move("tl_789ghi", {
     *         path: "new directory/new name"
     *     })
     */
    move(id: string, request?: Humanloop.UpdateToolRequest, requestOptions?: Tools.RequestOptions): Promise<Humanloop.ToolResponse>;
    /**
     * Get a list of all the versions of a Tool.
     *
     * @param {string} id - Unique identifier for the Tool.
     * @param {Humanloop.ListVersionsToolsIdVersionsGetRequest} request
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.listVersions("tl_789ghi")
     */
    listVersions(id: string, request?: Humanloop.ListVersionsToolsIdVersionsGetRequest, requestOptions?: Tools.RequestOptions): Promise<Humanloop.ListTools>;
    /**
     * Delete a version of the Tool.
     *
     * @param {string} id - Unique identifier for Tool.
     * @param {string} versionId - Unique identifier for the specific version of the Tool.
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.deleteToolVersion("id", "version_id")
     */
    deleteToolVersion(id: string, versionId: string, requestOptions?: Tools.RequestOptions): Promise<void>;
    /**
     * Update the name or description of the Tool version.
     *
     * @param {string} id - Unique identifier for Tool.
     * @param {string} versionId - Unique identifier for the specific version of the Tool.
     * @param {Humanloop.UpdateVersionRequest} request
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.updateToolVersion("id", "version_id", {})
     */
    updateToolVersion(id: string, versionId: string, request: Humanloop.UpdateVersionRequest, requestOptions?: Tools.RequestOptions): Promise<Humanloop.ToolResponse>;
    /**
     * Deploy Tool to an Environment.
     *
     * Set the deployed version for the specified Environment. This Prompt
     * will be used for calls made to the Tool in this Environment.
     *
     * @param {string} id - Unique identifier for Tool.
     * @param {string} environmentId - Unique identifier for the Environment to deploy the Version to.
     * @param {Humanloop.SetDeploymentToolsIdEnvironmentsEnvironmentIdPostRequest} request
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.setDeployment("tl_789ghi", "staging", {
     *         versionId: "tv_012jkl"
     *     })
     */
    setDeployment(id: string, environmentId: string, request: Humanloop.SetDeploymentToolsIdEnvironmentsEnvironmentIdPostRequest, requestOptions?: Tools.RequestOptions): Promise<Humanloop.ToolResponse>;
    /**
     * Remove deployed Tool from the Environment.
     *
     * Remove the deployed version for the specified Environment. This Tool
     * will no longer be used for calls made to the Tool in this Environment.
     *
     * @param {string} id - Unique identifier for Tool.
     * @param {string} environmentId - Unique identifier for the Environment to remove the deployment from.
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.removeDeployment("tl_789ghi", "staging")
     */
    removeDeployment(id: string, environmentId: string, requestOptions?: Tools.RequestOptions): Promise<void>;
    /**
     * List all Environments and their deployed versions for the Tool.
     *
     * @param {string} id - Unique identifier for Tool.
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.listEnvironments("tl_789ghi")
     */
    listEnvironments(id: string, requestOptions?: Tools.RequestOptions): Promise<Humanloop.FileEnvironmentResponse[]>;
    /**
     * Activate and deactivate Evaluators for monitoring the Tool.
     *
     * An activated Evaluator will automatically be run on all new Logs
     * within the Tool for monitoring purposes.
     *
     * @param {string} id
     * @param {Humanloop.EvaluatorActivationDeactivationRequest} request
     * @param {Tools.RequestOptions} requestOptions - Request-specific configuration.
     *
     * @throws {@link Humanloop.UnprocessableEntityError}
     *
     * @example
     *     await client.tools.updateMonitoring("tl_789ghi", {
     *         activate: [{
     *                 evaluatorVersionId: "evv_1abc4308abd"
     *             }]
     *     })
     */
    updateMonitoring(id: string, request: Humanloop.EvaluatorActivationDeactivationRequest, requestOptions?: Tools.RequestOptions): Promise<Humanloop.ToolResponse>;
    protected _getCustomAuthorizationHeaders(): Promise<{
        "X-API-KEY": string | undefined;
    }>;
}
