import { AttributeValue } from "@opentelemetry/api";
import { ReadableSpan } from "@opentelemetry/sdk-trace-base";
export type NestedDict = {
    [key: string]: NestedDict | AttributeValue;
};
export type NestedList = Array<NestedDict | AttributeValue>;
/**
 * Writes a Python-like object to the OpenTelemetry Span's attributes.
 * Converts complex objects into a linearized dictionary representation.
 *
 * @param span - OpenTelemetry span to write values to
 * @param value - Object to write to the span attributes
 * @param key - Key prefix for the span attributes
 */
export declare function writeToOpenTelemetrySpan(span: ReadableSpan, value: NestedDict | NestedList | AttributeValue | any[], key: string): void;
/**
 * Reads a value from the OpenTelemetry span attributes.
 * Reconstructs the original object structure from a key prefix.
 *
 * @param span - OpenTelemetry span to read values from
 * @param key - Key prefix to read from the span attributes
 * @returns Reconstructed object from the span attributes
 */
export declare function readFromOpenTelemetrySpan(span: ReadableSpan, key?: string): NestedDict;
/**
 * Determines if the span was created by an instrumentor for LLM provider clients.
 *
 * @param span - OpenTelemetry span to check
 * @returns True if the span corresponds to an LLM provider call, false otherwise
 */
export declare function isLLMProviderCall(span: ReadableSpan): boolean;
/**
 * Checks if the span was created by the Humanloop SDK.
 *
 * @param span - OpenTelemetry span to check
 * @returns True if the span was created by the Humanloop SDK, false otherwise
 */
export declare function isHumanloopSpan(span: ReadableSpan): boolean;
/**
 * Converts the output to JSON if it's not already a string.
 * Throws an error if the output is not JSON serializable.
 *
 * @param func - Function whose output is being converted
 * @param output - Output to be converted
 * @returns JSON string representation of the output
 */
export declare function jsonifyIfNotString(func: Function, output: any): string | undefined;
