"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.overloadLog = overloadLog;
exports.overloadCall = overloadCall;
const Client_1 = require("./api/resources/flows/client/Client");
const context_1 = require("./context");
const error_1 = require("./error");
function overloadLog(client) {
    const originalLog = client.log.bind(client);
    const _overloadedLog = (request, options) => __awaiter(this, void 0, void 0, function* () {
        const traceId = (0, context_1.getTraceId)();
        if (traceId !== undefined && client instanceof Client_1.Flows) {
            const context = (0, context_1.getDecoratorContext)();
            if (context === undefined) {
                throw new error_1.HumanloopRuntimeError("Internal error: trace_id context is set outside a decorator context.");
            }
            throw new error_1.HumanloopRuntimeError(`Using flows.log() is not allowed: Flow decorator for File ${context.path} manages the tracing and trace completion.`);
        }
        if (traceId !== undefined) {
            if ("traceParentId" in request) {
                console.warn("Ignoring trace_parent_id argument: the Flow decorator manages tracing.");
            }
            request = Object.assign(Object.assign({}, request), { traceParentId: traceId });
        }
        const evaluationContext = (0, context_1.getEvaluationContext)();
        if (evaluationContext !== undefined) {
            const [kwargsEval, evalCallback] = evaluationContext.logArgsWithContext({
                logArgs: request,
                forOtel: true,
                path: request.path,
            });
            try {
                // @ts-ignore Polymorphism alarms the type checker
                const response = yield originalLog(kwargsEval, options);
                if (evalCallback !== null) {
                    yield evalCallback(response.id);
                }
                return response;
            }
            catch (e) {
                throw new error_1.HumanloopRuntimeError(String(e));
            }
        }
        else {
            try {
                // @ts-ignore Polymorphism alarms the type checker
                return yield originalLog(request, options);
            }
            catch (e) {
                throw new error_1.HumanloopRuntimeError(String(e));
            }
        }
    });
    // @ts-ignore
    client.log = _overloadedLog.bind(client);
    // @ts-ignore
    client._log = originalLog.bind(client);
    return client;
}
function overloadCall(client) {
    const originalCall = client.call.bind(client);
    const _overloadedCall = (request, options) => __awaiter(this, void 0, void 0, function* () {
        const traceId = (0, context_1.getTraceId)();
        if (traceId !== undefined) {
            if ("traceParentId" in request) {
                console.warn("Ignoring trace_parent_id argument: the Flow decorator manages tracing.");
            }
            request = Object.assign(Object.assign({}, request), { traceParentId: traceId });
        }
        try {
            return yield originalCall(request, options);
        }
        catch (e) {
            throw new error_1.HumanloopRuntimeError(String(e));
        }
    });
    client.call = _overloadedCall.bind(client);
    return client;
}
